Index: image_fupload.module
===================================================================
--- image_fupload.module	(revision 1264)
+++ image_fupload.module	(revision 1536)
@@ -25,6 +25,11 @@
     'access arguments' => array('mass upload images'),
     'type' => MENU_CALLBACK,
   );
+  $items['fupload/js/flash-requirement-ko'] = array(
+    'page callback' => 'fupload_requirement_ko',
+    'access arguments' => array('mass upload images'),
+    'type' => MENU_CALLBACK,
+  );
   $items['node/add/%image_node_type/list_images'] = array(
     'title' => 'Edit Captions',
     'access arguments' => array('edit captions'),
@@ -400,3 +405,10 @@
   $content_types = node_get_types();
   return ($content_types[$node_type]->module == 'image');
 }
+
+/**
+ * Flash requirement are not satisfied by the browser
+ */
+function fupload_requirement_ko() {
+  drupal_set_message(t('Flash 9.0.28 or greater is required. You have been redirected on flashless form version.'), 'warning');
+}
Index: image_fupload_imagefield/image_fupload_imagefield.module
===================================================================
--- image_fupload_imagefield/image_fupload_imagefield.module	(revision 1264)
+++ image_fupload_imagefield/image_fupload_imagefield.module	(revision 1536)
@@ -73,6 +73,7 @@
       drupal_add_js($module_path .'/swfupload/swfupload.queue.js', 'module');
       drupal_add_js($module_path .'/swfupload/fileprogress.js', 'module');
       drupal_add_js($module_path .'/swfupload/handlers.js', 'module');
+      drupal_add_js($module_path .'/swfupload/swfupload.swfobject.js', 'module');
 
       // provide a link for further steps (preview list with editing) if permitted
       $redirect_url = '';
@@ -530,7 +531,7 @@
 function form_fields_destroy(&$form, $fields_to_remove = array()) {
   // collect information about fields being used by image preview list, if needed
   $fields = array();
-  
+
   if (count($fields_to_remove)) {
     foreach ($fields_to_remove as $key) {
       $elements = explode("_", $key, 2);
Index: README.txt
===================================================================
--- README.txt	(revision 1264)
+++ README.txt	(revision 1536)
@@ -17,7 +17,7 @@
 1.) Copy this directory to a suitable modules directory, 
     such as sites/all/modules
 2.) Download SWFUpload-Core v2.2.* at http://code.google.com/p/swfupload/ and extract
-    the following files from the zip file: swfupload.swf, swfupload.js, swfupload.queue.js
+    the following files from the zip file: swfupload.swf, swfupload.js, swfupload.queue.js, swfupload.swfobject.js
     Put these files into sites/all/modules/image_fupload/swfupload subdirectory
 3.) Activate the module and its submodules (if needed) in the module list.
     (dependency: image module or/and imagefield module)
Index: image_fupload_image/image_fupload_image.module
===================================================================
--- image_fupload_image/image_fupload_image.module	(revision 1264)
+++ image_fupload_image/image_fupload_image.module	(revision 1536)
@@ -38,6 +38,7 @@
     drupal_add_js($module_path .'/swfupload/swfupload.queue.js', 'module');
     drupal_add_js($module_path .'/swfupload/fileprogress.js', 'module');
     drupal_add_js($module_path .'/swfupload/handlers.js', 'module');
+    drupal_add_js($module_path .'/swfupload/swfupload.swfobject.js', 'module');
     /* Check if another step with editing options is provided  for this user*/
     $redirect_url = '';
     if (user_access('edit captions')) {

Index: swfupload-settings.tpl.php
===================================================================
--- swfupload-settings.tpl.php	(revision 1264)
+++ swfupload-settings.tpl.php	(revision 1536)
@@ -12,7 +12,8 @@
 var queue_complete = 0; // contains number of queued and successfully uploaded images
 var count_failed_uploads = 0; // Number of failed uploads
 
-window.onload = function() {
+Drupal.behaviors.imageFUpload = function(context) {
+  if ($('#spanUploadButton').length == 0) return;
   var settings = {
     flash_url : "<?php print $modulepath; ?>/swfupload/swfupload.swf",
     upload_url: "<?php print $uploadpath; ?>",  // Relative to the SWF file
@@ -46,11 +47,23 @@
     upload_error_handler : uploadError,
     upload_success_handler : uploadSuccess,
     upload_complete_handler : uploadComplete,
-    queue_complete_handler : queueComplete  // Queue plugin event
+    queue_complete_handler : queueComplete,  // Queue plugin event
+    //flash detection settings
+    minimum_flash_version: "9.0.28",
+    swfupload_load_failed_handler: swfuploadLoadFailed
   };
   swfu = new SWFUpload(settings);
 
 };
+/**
+* if flash requirement is not satisfied
+*/
+function swfuploadLoadFailed(event) {
+  //we reload the form without flash
+  $.ajax({ url: "/fupload/js/flash-requirement-ko", context: document.body, success: function(){
+        document.location = document.location +"/noflash";
+      }});
+}
 
 function startUploadProcess() {
   var redirect_url = "<?php print $redirect_url; ?>";